@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
 our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -11,6 +11,10 @@ our $scenario = {
     summary => 'Benchmark startup of classes using various accessor generators',
     module_startup => 1,
     modules => {
+        # include the generator modules here so we can show their versions in
+        # sample benchmark results produced by PWP:Bencher::Scenario
+        (map { $_=>0 } grep {defined} map { $classes->{$_}{generator} }
+             keys %$classes),
     },
     participants => [
         map {
@@ -35,7 +39,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.09 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.10 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -49,6 +53,30 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
+L<Class::Accessor> 0.34
+
+L<Class::Accessor::Array> 0.02
+
+L<Class::InsideOut> 1.13
+
+L<Class::Tiny> 1.004
+
+L<Class::XSAccessor> 1.19
+
+L<Class::XSAccessor::Array> 1.19
+
+L<Mo> 0.40
+
+L<Mojo::Base>
+
+L<Moo> 2.002004
+
+L<Moose> 2.1805
+
+L<Mouse> v2.4.5
+
+L<Object::Simple> 3.1703
+
 L<Perl::Examples::Accessors::Array> 0.08
 
 L<Perl::Examples::Accessors::ClassAccessor> 0.08
@@ -81,19 +109,15 @@ L<Perl::Examples::Accessors::Scalar> 0.08
 
 L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
+L<Simple::Accessor> 1.02
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
 
-L<Perl::Examples::Accessors::ObjectSimple>
-
-
-
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
+L<Perl::Examples::Accessors::SimpleAccessor>
 
 
 
@@ -103,84 +127,90 @@ L<Perl::Examples::Accessors::Mouse>
 
 
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
-
-L<Perl::Examples::Accessors::Mo>
-
-
-
 =item * Perl::Examples::Accessors::MojoBase (perl_code)
 
 L<Perl::Examples::Accessors::MojoBase>
 
 
 
-=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::Moose (perl_code)
-
-L<Perl::Examples::Accessors::Moose>
-
-
-
-=item * Perl::Examples::Accessors::ClassTiny (perl_code)
-
-L<Perl::Examples::Accessors::ClassTiny>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
-
-
-
-=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
-
-L<Perl::Examples::Accessors::SimpleAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Array (perl_code)
-
-L<Perl::Examples::Accessors::Array>
-
-
-
-=item * Perl::Examples::Accessors::Scalar (perl_code)
-
-L<Perl::Examples::Accessors::Scalar>
-
-
-
 =item * Perl::Examples::Accessors::ClassAccessor (perl_code)
 
 L<Perl::Examples::Accessors::ClassAccessor>
 
 
 
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
+
+
+
+=item * Perl::Examples::Accessors::Moose (perl_code)
+
+L<Perl::Examples::Accessors::Moose>
+
+
+
+=item * Perl::Examples::Accessors::Moo (perl_code)
+
+L<Perl::Examples::Accessors::Moo>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
+
+
+
+=item * Perl::Examples::Accessors::Scalar (perl_code)
+
+L<Perl::Examples::Accessors::Scalar>
+
+
+
+=item * Perl::Examples::Accessors::ClassTiny (perl_code)
+
+L<Perl::Examples::Accessors::ClassTiny>
+
+
+
 =item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
 
 L<Perl::Examples::Accessors::ClassXSAccessorArray>
 
 
 
+=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::Array (perl_code)
+
+L<Perl::Examples::Accessors::Array>
+
+
+
 =item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
 
 L<Perl::Examples::Accessors::ClassInsideOut>
 
 
 
+=item * Perl::Examples::Accessors::Mo (perl_code)
+
+L<Perl::Examples::Accessors::Mo>
+
+
+
+=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+
+L<Perl::Examples::Accessors::ObjectSimple>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -193,23 +223,23 @@ Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
- | Perl::Examples::Accessors::Moose                |     170   |    165.9               |        1   |   0.00081 |      20 |
- | Perl::Examples::Accessors::Moo                  |      31   |     26.9               |        5.5 | 9.9e-05   |      20 |
- | Perl::Examples::Accessors::Mouse                |      26   |     21.9               |        6.7 | 3.5e-05   |      20 |
- | Perl::Examples::Accessors::MojoBase             |      17   |     12.9               |       10   |   0.00015 |      20 |
- | Perl::Examples::Accessors::ClassInsideOut       |      16   |     11.9               |       11   |   5e-05   |      20 |
- | Perl::Examples::Accessors::ClassTiny            |      14   |      9.9               |       12   | 3.5e-05   |      20 |
- | Perl::Examples::Accessors::ObjectSimple         |      13   |      8.9               |       13   |   0.0001  |      20 |
- | Perl::Examples::Accessors::ClassXSAccessorArray |      12   |      7.9               |       14   | 5.7e-05   |      20 |
- | Perl::Examples::Accessors::ClassXSAccessor      |      12   |      7.9               |       15   | 2.2e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessor        |      12   |      7.9               |       15   | 5.8e-05   |      20 |
- | Perl::Examples::Accessors::SimpleAccessor       |       7.5 |      3.4               |       23   | 1.7e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessorArray   |       6.9 |      2.8               |       25   | 2.3e-05   |      20 |
- | Perl::Examples::Accessors::Mo                   |       6.7 |      2.6               |       26   | 2.1e-05   |      20 |
- | Perl::Examples::Accessors::Scalar               |       5.5 |      1.4               |       31   | 3.6e-05   |      20 |
- | Perl::Examples::Accessors::Array                |       5   |      0.9               |       35   | 1.9e-05   |      20 |
- | Perl::Examples::Accessors::Hash                 |       4.9 |      0.800000000000001 |       35   | 8.5e-06   |      20 |
- | perl -e1 (baseline)                             |       4.1 |      0                 |       42   | 1.5e-05   |      20 |
+ | Perl::Examples::Accessors::Moose                |     200   |                  195.5 |        1   |   0.0025  |      22 |
+ | Perl::Examples::Accessors::Moo                  |      32   |                   27.5 |        5.8 | 6.5e-05   |      20 |
+ | Perl::Examples::Accessors::Mouse                |      26   |                   21.5 |        7.2 | 7.2e-05   |      20 |
+ | Perl::Examples::Accessors::ClassInsideOut       |      16   |                   11.5 |       11   | 8.8e-05   |      20 |
+ | Perl::Examples::Accessors::MojoBase             |      16   |                   11.5 |       12   | 7.7e-05   |      20 |
+ | Perl::Examples::Accessors::ClassTiny            |      14   |                    9.5 |       13   | 5.7e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectSimple         |      10   |                    5.5 |       10   |   0.00015 |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessorArray |      13   |                    8.5 |       15   | 8.8e-05   |      22 |
+ | Perl::Examples::Accessors::ClassXSAccessor      |      13   |                    8.5 |       15   | 9.9e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessor        |      12   |                    7.5 |       15   | 5.7e-05   |      21 |
+ | Perl::Examples::Accessors::SimpleAccessor       |       6.9 |                    2.4 |       27   | 2.3e-05   |      20 |
+ | Perl::Examples::Accessors::Mo                   |       6.6 |                    2.1 |       28   | 2.6e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessorArray   |       6.6 |                    2.1 |       28   | 2.1e-05   |      20 |
+ | Perl::Examples::Accessors::Scalar               |       4.8 |                    0.3 |       39   | 3.6e-05   |      20 |
+ | perl -e1 (baseline)                             |       4.5 |                    0   |       41   | 4.2e-05   |      20 |
+ | Perl::Examples::Accessors::Array                |       4.5 |                    0   |       41   | 1.7e-05   |      20 |
+ | Perl::Examples::Accessors::Hash                 |       4.5 |                    0   |       42   | 2.2e-05   |      20 |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
