@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
 our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -10,7 +10,13 @@ my $classes = \%Bencher::ScenarioUtil::Accessors::classes;
 our $scenario = {
     summary => 'Benchmark object construction',
     modules => {
+        # force minimum version
         'Perl::Examples::Accessors' => {version=>0.05},
+
+        # include the generator modules here so we can show their versions in
+        # sample benchmark results produced by PWP:Bencher::Scenario
+        (map { $_=>0 } grep {defined} map { $classes->{$_}{generator} }
+             keys %$classes),
     },
     participants => [
         map {
@@ -40,7 +46,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.09 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.10 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -58,6 +64,30 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
+L<Class::Accessor> 0.34
+
+L<Class::Accessor::Array> 0.02
+
+L<Class::InsideOut> 1.13
+
+L<Class::Tiny> 1.004
+
+L<Class::XSAccessor> 1.19
+
+L<Class::XSAccessor::Array> 1.19
+
+L<Mo> 0.40
+
+L<Mojo::Base>
+
+L<Moo> 2.002004
+
+L<Moose> 2.1805
+
+L<Mouse> v2.4.5
+
+L<Object::Simple> 3.1703
+
 L<Perl::Examples::Accessors> 0.08
 
 L<Perl::Examples::Accessors::Array> 0.08
@@ -92,23 +122,17 @@ L<Perl::Examples::Accessors::Scalar> 0.08
 
 L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
+L<Simple::Accessor> 1.02
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Object::Simple (perl_code)
+=item * Simple::Accessor (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ObjectSimple->new
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
+ Perl::Examples::Accessors::SimpleAccessor->new
 
 
 
@@ -120,14 +144,6 @@ Code template:
 
 
 
-=item * Mo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mo->new
-
-
-
 =item * Mojo::Base (perl_code)
 
 Code template:
@@ -136,70 +152,6 @@ Code template:
 
 
 
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessorArray->new
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moose->new
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassTiny->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::SimpleAccessor->new
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
-
-
-
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
 =item * Class::Accessor (perl_code)
 
 Code template:
@@ -208,6 +160,54 @@ Code template:
 
 
 
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * Moose (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * Moo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moo->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassTiny->new
+
+
+
 =item * Class::XSAccessor::Array (perl_code)
 
 Code template:
@@ -216,6 +216,22 @@ Code template:
 
 
 
+=item * Class::Accessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessorArray->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -224,6 +240,22 @@ Code template:
 
 
 
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ObjectSimple->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -236,22 +268,22 @@ Benchmark with default options (C<< bencher -m Accessors::Construction >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Class::InsideOut            |    190000 |     5.2   |       1    | 6.7e-09 |      20 |
- | Simple::Accessor            |    330000 |     3     |       1.7  | 6.5e-09 |      21 |
- | Class::Tiny                 |    380000 |     2.6   |       2    | 3.3e-09 |      20 |
- | Moose                       |    520000 |     1.9   |       2.7  | 3.3e-09 |      20 |
- | Mo                          |    800000 |     1.3   |       4.2  | 1.8e-09 |      26 |
- | Moo                         |   1050000 |     0.949 |       5.52 | 1.4e-10 |      20 |
- | Class::Accessor             |   1100000 |     0.91  |       5.7  | 1.1e-09 |      25 |
- | Mouse                       |   1400000 |     0.7   |       7.5  | 1.8e-09 |      26 |
- | no generator (array-based)  |   1740000 |     0.576 |       9.1  | 2.1e-10 |      21 |
- | Object::Simple              |   2200000 |     0.46  |      11    | 7.5e-10 |      25 |
- | Mojo::Base                  |   2200000 |     0.45  |      12    | 8.4e-10 |      20 |
- | no generator (hash-based)   |   2230000 |     0.448 |      11.7  | 9.3e-11 |      20 |
- | Class::Accessor::Array      |   2470000 |     0.404 |      13    | 9.3e-11 |      20 |
- | no generator (scalar-based) |   2480000 |     0.403 |      13    | 9.3e-11 |      21 |
- | Class::XSAccessor           |   3540000 |     0.282 |      18.6  | 1.3e-10 |      24 |
- | Class::XSAccessor::Array    |   3600000 |     0.28  |      19    |   1e-09 |      29 |
+ | Class::InsideOut            |    188000 |    5.31   |       1    |   5e-09 |      20 |
+ | Simple::Accessor            |    330000 |    3      |       1.8  | 1.3e-08 |      20 |
+ | Class::Tiny                 |    380000 |    2.6    |       2    | 7.5e-09 |      20 |
+ | Moose                       |    539000 |    1.86   |       2.86 | 8.3e-10 |      20 |
+ | Mo                          |    810000 |    1.2    |       4.3  | 3.7e-09 |      20 |
+ | Moo                         |   1030000 |    0.968  |       5.49 |   1e-10 |      20 |
+ | Class::Accessor             |   1100000 |    0.88   |       6.1  | 1.7e-09 |      20 |
+ | Mouse                       |   1500000 |    0.69   |       7.7  | 3.3e-09 |      20 |
+ | no generator (array-based)  |   1780000 |    0.56   |       9.48 | 2.1e-10 |      20 |
+ | no generator (hash-based)   |   2170000 |    0.4608 |      11.53 | 1.1e-11 |      28 |
+ | Object::Simple              |   2200000 |    0.46   |      12    |   1e-09 |      20 |
+ | Mojo::Base                  |   2190000 |    0.456  |      11.6  | 2.7e-10 |      24 |
+ | Class::Accessor::Array      |   2390000 |    0.418  |      12.7  | 4.6e-11 |      25 |
+ | no generator (scalar-based) |   2450000 |    0.409  |      13    | 2.1e-10 |      20 |
+ | Class::XSAccessor           |   3400000 |    0.29   |      18    | 4.2e-10 |      20 |
+ | Class::XSAccessor::Array    |   3600000 |    0.28   |      19    | 3.3e-10 |      32 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
