@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
 our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -10,6 +10,10 @@ my $classes = \%Bencher::ScenarioUtil::Accessors::classes;
 our $scenario = {
     summary => 'Benchmark attribute write/set',
     modules => {
+        # include the generator modules here so we can show their versions in
+        # sample benchmark results produced by PWP:Bencher::Scenario
+        (map { $_=>0 } grep {defined} map { $classes->{$_}{generator} }
+             keys %$classes),
     },
     participants => [
         (map {
@@ -50,7 +54,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.09 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.10 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -68,6 +72,30 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
+L<Class::Accessor> 0.34
+
+L<Class::Accessor::Array> 0.02
+
+L<Class::InsideOut> 1.13
+
+L<Class::Tiny> 1.004
+
+L<Class::XSAccessor> 1.19
+
+L<Class::XSAccessor::Array> 1.19
+
+L<Mo> 0.40
+
+L<Mojo::Base>
+
+L<Moo> 2.002004
+
+L<Moose> 2.1805
+
+L<Mouse> v2.4.5
+
+L<Object::Simple> 3.1703
+
 L<Perl::Examples::Accessors::Array> 0.08
 
 L<Perl::Examples::Accessors::ClassAccessor> 0.08
@@ -98,23 +126,17 @@ L<Perl::Examples::Accessors::ObjectSimple> 0.08
 
 L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
+L<Simple::Accessor> 1.02
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Object::Simple (perl_code)
+=item * Simple::Accessor (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
 
 
 
@@ -126,14 +148,6 @@ Code template:
 
 
 
-=item * Mo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
-
-
-
 =item * Mojo::Base (perl_code)
 
 Code template:
@@ -142,62 +156,6 @@ Code template:
 
 
 
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
-
-
-
 =item * Class::Accessor (perl_code)
 
 Code template:
@@ -206,6 +164,46 @@ Code template:
 
 
 
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Moose (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
+
+
+
+=item * Moo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
+
+
+
 =item * Class::XSAccessor::Array (perl_code)
 
 Code template:
@@ -214,6 +212,22 @@ Code template:
 
 
 
+=item * Class::Accessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -222,6 +236,22 @@ Code template:
 
 
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
+
+
+
 =item * raw hash access (perl_code)
 
 Code template:
@@ -250,23 +280,23 @@ Benchmark with default options (C<< bencher -m Accessors::Set >>):
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Simple::Accessor           |    190000 |    5.2    |       1    | 2.7e-08 |      20 |
- | Class::Accessor            |   1600000 |    0.62   |       8.3  | 1.7e-09 |      20 |
- | Class::InsideOut           |   2007000 |    0.4982 |      10.43 | 4.6e-11 |      20 |
- | Moose                      |   3600000 |    0.28   |      19    | 4.2e-10 |      20 |
- | Mojo::Base                 |   3620000 |    0.276  |      18.8  | 5.8e-11 |      20 |
- | Class::Tiny                |   3720000 |    0.269  |      19.4  | 4.6e-11 |      20 |
- | Class::Accessor::Array     |   4000000 |    0.25   |      21    | 4.2e-10 |      20 |
- | Mo                         |   4200000 |    0.24   |      22    | 1.2e-09 |      21 |
- | Object::Simple             |   4380000 |    0.228  |      22.8  | 1.5e-10 |      20 |
- | no generator (hash-based)  |   4530000 |    0.221  |      23.6  | 4.6e-11 |      20 |
- | no generator (array-based) |   5100000 |    0.2    |      26    | 3.8e-10 |      27 |
- | Mouse                      |   9060000 |    0.11   |      47.1  | 4.7e-11 |      22 |
- | Class::XSAccessor          |  10200000 |    0.0984 |      52.8  | 4.5e-11 |      20 |
- | Class::XSAccessor::Array   |  11500000 |    0.0872 |      59.6  | 6.9e-11 |      20 |
- | Moo                        |  12000000 |    0.083  |      63    | 1.7e-10 |      22 |
- | raw hash access            |  18200000 |    0.0548 |      94.8  | 4.6e-11 |      20 |
- | raw array access           |  24000000 |    0.042  |     120    | 4.6e-11 |      20 |
+ | Simple::Accessor           |    200000 |    5.1    |        1   |   7e-09 |      28 |
+ | Class::Accessor            |   1600000 |    0.64   |        7.9 | 8.3e-10 |      20 |
+ | Class::InsideOut           |   1900000 |    0.54   |        9.5 | 1.8e-09 |      21 |
+ | Moose                      |   3600000 |    0.28   |       18   | 8.1e-10 |      21 |
+ | Mojo::Base                 |   3610000 |    0.277  |       18.4 | 1.1e-10 |      20 |
+ | Class::Tiny                |   3680000 |    0.271  |       18.8 | 1.1e-10 |      20 |
+ | Class::Accessor::Array     |   3800000 |    0.26   |       19   | 1.6e-09 |      21 |
+ | Mo                         |   4130000 |    0.242  |       21.1 | 1.3e-10 |      27 |
+ | Object::Simple             |   4100000 |    0.24   |       21   |   4e-10 |      22 |
+ | no generator (array-based) |   4400000 |    0.23   |       23   | 4.2e-10 |      20 |
+ | no generator (hash-based)  |   4610000 |    0.217  |       23.5 | 4.6e-11 |      34 |
+ | Mouse                      |   7790000 |    0.128  |       39.7 | 4.7e-11 |      23 |
+ | Moo                        |   9810000 |    0.102  |       50   |   7e-11 |      20 |
+ | Class::XSAccessor          |  10000000 |    0.097  |       52   | 2.1e-10 |      20 |
+ | Class::XSAccessor::Array   |  12000000 |    0.0834 |       61.1 | 4.7e-11 |      29 |
+ | raw hash access            |  18000000 |    0.054  |       94   |   7e-11 |      20 |
+ | raw array access           |  23000000 |    0.044  |      120   | 2.1e-10 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
